HilbertCCA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertCCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertCCA.__init__
      ~HilbertCCA.components
      ~HilbertCCA.components_amplitude
      ~HilbertCCA.components_phase
      ~HilbertCCA.compute
      ~HilbertCCA.correlation_coefficients_X
      ~HilbertCCA.correlation_coefficients_Y
      ~HilbertCCA.cross_correlation_coefficients
      ~HilbertCCA.deserialize
      ~HilbertCCA.fit
      ~HilbertCCA.fraction_variance_X_explained_by_X
      ~HilbertCCA.fraction_variance_Y_explained_by_X
      ~HilbertCCA.fraction_variance_Y_explained_by_Y
      ~HilbertCCA.get_params
      ~HilbertCCA.get_serialization_attrs
      ~HilbertCCA.heterogeneous_patterns
      ~HilbertCCA.homogeneous_patterns
      ~HilbertCCA.inverse_transform
      ~HilbertCCA.load
      ~HilbertCCA.predict
      ~HilbertCCA.save
      ~HilbertCCA.scores
      ~HilbertCCA.scores_amplitude
      ~HilbertCCA.scores_phase
      ~HilbertCCA.serialize
      ~HilbertCCA.squared_covariance_fraction
      ~HilbertCCA.transform
   
   

   
   
   